@@ -1,5 +1,5 @@
 # Pure zero-dependency JSON-RPC 2.0 implementation.
-# Copyright © 2022 Andrew Malchuk. All rights reserved.
+# Copyright © 2022-2023 Andrew Malchuk. All rights reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -13,55 +13,21 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from abc import ABCMeta, abstractmethod
-from collections import UserDict as Dict
+from collections import UserDict
 from collections.abc import Callable
 from functools import partial
 from inspect import BoundArguments, isfunction, signature
-from typing import Any, Final, Protocol, TypeAlias, TypeVar, cast, overload
+from typing import Any, Final, TypeAlias, TypeVar, overload
 
 from ._errors import Error, ErrorEnum
 
 __all__: Final[tuple[str, ...]] = ("Dispatcher",)
 
 _AnyCallable: TypeAlias = Callable[..., Any]
-_FuncT = TypeVar("_FuncT", bound=_AnyCallable)
+_Func = TypeVar("_Func", bound=_AnyCallable)
 
 
-class register_decorator(Protocol):
-    @overload
-    def __call__(self, user_function: _FuncT, /) -> _FuncT:
-        ...
-
-    @overload
-    def __call__(self, user_function: _FuncT, *, function_name: str | None = ...) -> _FuncT:
-        ...
-
-    @overload
-    def __call__(self, *, function_name: str | None = ...) -> Callable[[_FuncT], _FuncT]:
-        ...
-
-
-class BaseDispatcher(Dict[str, _AnyCallable], metaclass=ABCMeta):
-    __slots__: tuple[str, ...] = ()
-
-    def __hash__(self) -> int:
-        return hash(frozenset(self.items()))
-
-    def __repr__(self) -> str:
-        return f"{self.__class__.__name__}({self.data!r})"
-
-    @property
-    @abstractmethod
-    def register(self) -> register_decorator:
-        raise NotImplementedError
-
-    @abstractmethod
-    def dispatch(self, function_name: str, /, *args: Any, **kwargs: Any) -> Any:
-        raise NotImplementedError
-
-
-class Dispatcher(BaseDispatcher):
+class Dispatcher(UserDict[str, _AnyCallable]):
     """
     The :py:class:`collections.UserDict` subclass representing the storage of user-defined functions.
 
@@ -75,10 +41,24 @@ class Dispatcher(BaseDispatcher):
 
     __slots__: tuple[str, ...] = ()
 
-    @property
-    def register(self) -> register_decorator:
+    def __repr__(self) -> str:
+        return f"{self.__class__.__qualname__}({self.data!r})"
+
+    @overload
+    def register(self, user_function: _Func, /) -> _Func:
+        ...
+
+    @overload
+    def register(self, user_function: _Func, *, function_name: str | None = ...) -> _Func:
+        ...
+
+    @overload
+    def register(self, *, function_name: str | None = ...) -> Callable[[_Func], _Func]:
+        ...
+
+    def register(self, user_function: _Func | None = None, *, function_name: str | None = None) -> Any:
         """
-        Returns a decorator for the registering user-defined functions.
+        Adds a user-defined function to the dispatcher.
 
         Example usage::
 
@@ -98,21 +78,17 @@ class Dispatcher(BaseDispatcher):
             or function with the provided name is already defined in the :class:`jsonrpc.Dispatcher` class.
         :returns: The unmodified ``user_function`` object, passed in the parameters.
         """
+        if user_function is None:
+            return partial(self.register, function_name=function_name)
 
-        def wrapper(user_function: _FuncT | None = None, *, function_name: str | None = None) -> _FuncT | Callable[[_FuncT], _FuncT]:
-            if user_function is None:
-                return cast(Callable[[_FuncT], _FuncT], partial(wrapper, function_name=function_name))
+        if not isfunction(user_function):
+            raise RuntimeError(f"{type(user_function).__name__!r} isn't a user-defined function")
 
-            if not isfunction(user_function):
-                raise RuntimeError(f"{type(user_function).__name__!r} isn't a user-defined function")
+        if (function_name := user_function.__name__ if function_name is None else function_name) in self:
+            raise RuntimeError(f"{function_name!r} is already defined in {self[function_name].__module__!r}")
 
-            if (function_name := user_function.__name__ if function_name is None else function_name) in self:
-                raise RuntimeError(f"{function_name!r} is already defined in {self[function_name].__module__!r}")
-
-            self[function_name] = user_function
-            return user_function
-
-        return cast(register_decorator, wrapper)
+        self[function_name] = user_function
+        return user_function
 
     def dispatch(self, function_name: str, /, *args: Any, **kwargs: Any) -> Any:
         """
