@@ -1,5 +1,5 @@
 # Pure zero-dependency JSON-RPC 2.0 implementation.
-# Copyright © 2022 Andrew Malchuk. All rights reserved.
+# Copyright © 2022-2023 Andrew Malchuk. All rights reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -21,6 +21,7 @@ __all__: Final[tuple[str, ...]] = (
     "Headers",
     "InputStream",
     "OptExcInfo",
+    "Serializer",
     "StartResponse",
     "WSGIEnvironment",
 )
@@ -31,16 +32,24 @@ WSGIEnvironment: TypeAlias = dict[str, Any]
 
 
 class StartResponse(Protocol):
-    def __call__(self, __status: str, __headers: Headers, __exc_info: OptExcInfo | None = ...) -> Any:
+    def __call__(self, status: str, headers: Headers, exc_info: OptExcInfo | None = ..., /) -> Any:
         ...
 
 
 class InputStream(Iterable[bytes], Protocol):
-    def read(self, __size: int = ...) -> bytes:
+    def read(self, size: int = ..., /) -> bytes:
         ...
 
-    def readline(self, __size: int = ...) -> bytes:
+    def readline(self, size: int = ..., /) -> bytes:
         ...
 
-    def readlines(self, __hint: int = ...) -> Iterator[bytes]:
+    def readlines(self, hint: int = ..., /) -> Iterator[bytes]:
+        ...
+
+
+class Serializer(Protocol):
+    def serialize(self, obj: Any, /) -> bytes:
+        ...
+
+    def deserialize(self, obj: bytes, /) -> Any:
         ...
