@@ -1,5 +1,5 @@
 # Pure zero-dependency JSON-RPC 2.0 implementation.
-# Copyright © 2022 Andrew Malchuk. All rights reserved.
+# Copyright © 2022-2023 Andrew Malchuk. All rights reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -14,7 +14,7 @@
 # limitations under the License.
 
 from collections.abc import Iterable, MutableMapping
-from typing import Any, Final, Literal, TypeGuard
+from typing import Any, Final, Literal, TypeGuard, final
 
 __all__: Final[tuple[str, ...]] = (
     "is_iterable",
@@ -24,7 +24,7 @@ __all__: Final[tuple[str, ...]] = (
 )
 
 
-def is_iterable(obj: Any) -> TypeGuard[Iterable[Any]]:
+def is_iterable(obj: Any, /) -> TypeGuard[Iterable[Any]]:
     try:
         iter(obj)
     except TypeError:
@@ -33,7 +33,7 @@ def is_iterable(obj: Any) -> TypeGuard[Iterable[Any]]:
         return True
 
 
-def make_hashable(obj: Any) -> Any:
+def make_hashable(obj: Any, /) -> Any:
     if isinstance(obj, MutableMapping):
         return tuple((key, make_hashable(value)) for key, value in sorted(obj.items()))
 
@@ -50,6 +50,7 @@ def make_hashable(obj: Any) -> Any:
     return obj
 
 
+@final
 class UndefinedType:
     __slots__: tuple[str, ...] = ()
 
