@@ -151,7 +151,7 @@ class WSGIHandler(UserDict[str, Any], _SerializableMixIn):
             print_exception(exc, file=environ["wsgi.errors"])
             return wsgi_response(status=HTTPStatus.INTERNAL_SERVER_ERROR, exc_info=exc_info())
 
-    def _read_request_body(self, environ: WSGIEnvironment, /) -> bytes:
+    def _read_request_body(self, environ: WSGIEnvironment, *, chunk_size: int = DEFAULT_BUFFER_SIZE) -> bytes:
         try:
             content_length: int = int(environ["CONTENT_LENGTH"])
         except (KeyError, ValueError):
@@ -163,7 +163,7 @@ class WSGIHandler(UserDict[str, Any], _SerializableMixIn):
             # Ensure to disallow reading the stream more bytes
             # than specified by "Content-Length" header:
             while content_length > 0:
-                if not (chunk := stream.read(min(content_length, DEFAULT_BUFFER_SIZE))):
+                if not (chunk := stream.read(min(content_length, chunk_size))):
                     raise EOFError(f"Client disconnected, {content_length:d} more bytes were expected")
 
                 # Appends the chunk of request body to the buffer
@@ -192,4 +192,12 @@ class WSGIHandler(UserDict[str, Any], _SerializableMixIn):
             headers.sort()
 
         start_response(f"{status.value:d}\u0020{status.phrase!s}", headers, exc_info)
-        yield response_body
+        return self._chunked_response(response_body)
+
+    def _chunked_response(self, response_body: bytes, *, chunk_size: int = DEFAULT_BUFFER_SIZE) -> Iterator[bytes]:
+        if not response_body:
+            yield b""
+            return
+
+        for offset in range(0, len(response_body), chunk_size):
+            yield response_body[offset : offset + chunk_size]
